@@ -102,7 +102,9 @@ def _read_list_files_in_directory(directory: str) -> Iterator[str]:
             try:
                 with list_file.open(encoding="utf-8") as fd:
                     for line in fd:
-                        yield line.strip()
+                        stripped = line.strip()
+                        if stripped and not stripped.startswith("#"):
+                            yield stripped
             except OSError:
                 continue
     except OSError:
@@ -715,7 +717,7 @@ class Report(problem_report.ProblemReport):
 
     def add_proc_info(
         self,
-        pid: int | str | None = None,
+        pid: int | None = None,
         proc_pid_fd: int | None = None,
         extraenv: Iterable[str] | None = None,
     ) -> None:
@@ -742,8 +744,6 @@ class Report(problem_report.ProblemReport):
         - ProcAttrCurrent: /proc/pid/attr/current contents, if not "unconfined"
         - CurrentDesktop: Value of $XDG_CURRENT_DESKTOP, if present
         """
-        if isinstance(pid, str):
-            pid = int(pid)
         if not proc_pid_fd:
             if not pid:
                 pid = self.pid or os.getpid()
@@ -950,7 +950,7 @@ class Report(problem_report.ProblemReport):
             "Stacktrace": "bt full",
             "ThreadStacktrace": "thread apply all bt full",
             "AssertionMessage": "print __abort_msg->msg",
-            "GLibAssertionMessage": "print __glib_assert_msg",
+            "GLibAssertionMessage": "print (char*) __glib_assert_msg",
             "NihAssertionMessage": "print (char*) __nih_abort_msg",
         }
         gdb_cmd, environ = self.gdb_command(rootdir, gdb_sandbox)
@@ -1242,7 +1242,7 @@ class Report(problem_report.ProblemReport):
         try:
             with urllib.request.urlopen(url) as request:
                 patterns = request.read().decode("UTF-8", errors="replace")
-        except (OSError, urllib.error.URLError):
+        except OSError:
             # doesn't exist or failed to load
             return None
 
@@ -1858,6 +1858,25 @@ class Report(problem_report.ProblemReport):
                     else:
                         self[k] = pattern.sub(repl, self[k])
 
+    def _provide_uncompressed_coredump_file(self) -> str:
+        coredump = self["CoreDump"]
+        assert not isinstance(coredump, str)
+        if isinstance(coredump, bytes):
+            (fd, core) = tempfile.mkstemp(prefix="apport_core_")
+            atexit.register(os.unlink, core)
+            os.write(fd, coredump)
+            os.close(fd)
+        elif isinstance(coredump, problem_report.CompressedValue):
+            (fd, core) = tempfile.mkstemp(prefix="apport_core_")
+            atexit.register(os.unlink, core)
+            os.close(fd)
+            with open(core, "wb") as f:
+                coredump.write(f)
+        else:
+            # value is a file path
+            core = coredump[0]
+        return core
+
     def gdb_command(
         self, sandbox: str | None, gdb_sandbox: str | None = None
     ) -> tuple[list[str], dict[str, str]]:
@@ -1927,21 +1946,7 @@ class Report(problem_report.ProblemReport):
         command += ["--ex", f'file "{executable}"']
 
         if "CoreDump" in self:
-            if hasattr(self["CoreDump"], "find"):
-                (fd, core) = tempfile.mkstemp(prefix="apport_core_")
-                atexit.register(os.unlink, core)
-                os.write(fd, self["CoreDump"])
-                os.close(fd)
-            elif isinstance(self["CoreDump"], problem_report.CompressedValue):
-                (fd, core) = tempfile.mkstemp(prefix="apport_core_")
-                atexit.register(os.unlink, core)
-                os.close(fd)
-                with open(core, "wb") as f:
-                    self["CoreDump"].write(f)
-            else:
-                # value is a file path
-                core = self["CoreDump"][0]
-
+            core = self._provide_uncompressed_coredump_file()
             command += ["--ex", "core-file " + core]
 
         return command, environ
